@@ -2,23 +2,25 @@ package Test2::API;
 use strict;
 use warnings;
 
-our $VERSION = '0.000042';
+our $VERSION = '0.000043';
+$VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 my $INST;
 my $ENDING = 0;
-sub _set_is_end { $ENDING = 1 }
+sub test2_set_is_end { ($ENDING) = @_ ? @_ : (1) }
+sub test2_get_is_end { $ENDING }
 
 use Test2::API::Instance(\$INST);
 # Set the exit status
 END {
-    _set_is_end(); # See gh #16
+    test2_set_is_end(); # See gh #16
     $INST->set_exit();
 }
 
 # See gh #16
 {
     no warnings;
-    INIT { eval 'END { _set_is_end() }; 1' or die $@ }
+    INIT { eval 'END { test2_set_is_end() }; 1' or die $@ }
 }
 
 BEGIN {
@@ -61,6 +63,9 @@ our @EXPORT_OK = qw{
     test2_init_done
     test2_load_done
 
+    test2_set_is_end
+    test2_get_is_end
+
     test2_pid
     test2_tid
     test2_stack
@@ -238,7 +243,7 @@ sub context {
     $_->(\%params) for @$ACQUIRE_CBS;
     map $_->(\%params), @{$hub->{_context_acquire}} if $hub->{_context_acquire};
 
-    # This is for https://github.com/Test-More/Test2/issues/16
+    # This is for https://github.com/Test-More/test-more/issues/16
     # and https://rt.perl.org/Public/Bug/Display.html?id=127774
     my $phase = ${^GLOBAL_PHASE} || 'NA';
     my $end_phase = $ENDING || $phase eq 'END' || $phase eq 'DESTRUCT';
@@ -526,10 +531,6 @@ __END__
 
 Test2::API - Primary interface for writing Test2 based testing tools.
 
-=head1 EXPERIMENTAL RELEASE
-
-This is an experimental release. Using this right now is not recommended.
-
 =head1 ***INTERNALS NOTE***
 
 B<The internals of this package are subject to change at any time!> The public
@@ -604,6 +605,8 @@ generated by the test system:
     use Test2::API qw{
         test2_init_done
         test2_stack
+        test2_set_is_end
+        test2_get_is_end
         test2_ipc
         test2_formatter_set
         test2_formatter
@@ -1006,6 +1009,22 @@ This will simply return the boolean value of the loaded flag. If Test2 has
 finished loading this will be true, otherwise false. Loading is considered
 complete the first time a tool requests a context.
 
+=item test2_set_is_end()
+
+=item test2_set_is_end($bool)
+
+This is used to toggle Test2's belief that the END phase has already started.
+With no arguments this will set it to true. With arguments it will set it to
+the first argument's value.
+
+This is used to prevent the use of C<caller()> in END blocks which can cause
+segfaults. This is only necessary in some persistent environments that may have
+multiple END phases.
+
+=item $bool = test2_get_is_end()
+
+Check if test2 believes it is the END phase.
+
 =item $stack = test2_stack()
 
 This will return the global L<Test2::API::Stack> instance. If this has not
@@ -1226,7 +1245,7 @@ can be added to this package.
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
-F<http://github.com/Test-More/Test2/>.
+F<http://github.com/Test-More/test-more/>.
 
 =head1 MAINTAINERS
 
@@ -1246,7 +1265,7 @@ F<http://github.com/Test-More/Test2/>.
 
 =head1 COPYRIGHT
 
-Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
+Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
