@@ -2,7 +2,8 @@ package Test2::Formatter;
 use strict;
 use warnings;
 
-our $VERSION = '0.000042';
+our $VERSION = '0.000043';
+$VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 my %ADDED;
 sub import {
@@ -27,10 +28,6 @@ __END__
 
 Test2::Formatter - Namespace for formatters.
 
-=head1 EXPERIMENTAL RELEASE
-
-This is an experimental release. Using this right now is not recommended.
-
 =head1 DESCRIPTION
 
 This is the namespace for formatters. This is an empty package.
@@ -60,14 +57,14 @@ this even is not itself an assertion. The assertion number may be any inyeger 0
 or greator, and may be undefined in some cases.
 
 The C<hide_buffered()> method must return a boolean. This is used to tell
-buffered subtests wether or not to send it events as they are being buffered.
+buffered subtests whether or not to send it events as they are being buffered.
 See L<Test2::API/"run_subtest(...)"> for more information.
 
 
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
-F<http://github.com/Test-More/Test2/>.
+F<http://github.com/Test-More/test-more/>.
 
 =head1 MAINTAINERS
 
@@ -87,7 +84,7 @@ F<http://github.com/Test-More/Test2/>.
 
 =head1 COPYRIGHT
 
-Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
+Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
