@@ -2,7 +2,8 @@ package Test2::IPC;
 use strict;
 use warnings;
 
-our $VERSION = '0.000042';
+our $VERSION = '0.000043';
+$VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 use Test2::API::Instance;
 use Test2::Util qw/get_tid/;
@@ -87,10 +88,6 @@ __END__
 
 Test2::IPC - Turn on IPC for threading or forking support.
 
-=head1 EXPERIMENTAL RELEASE
-
-This is an experimental release. Using this right now is not recommended.
-
 =head1 SYNOPSIS
 
 You should C<use Test2::IPC;> as early as possible in your test file. If you
@@ -112,7 +109,7 @@ Cull allows you to collect results from other processes or threads on demand.
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
-F<http://github.com/Test-More/Test2/>.
+F<http://github.com/Test-More/test-more/>.
 
 =head1 MAINTAINERS
 
@@ -132,7 +129,7 @@ F<http://github.com/Test-More/Test2/>.
 
 =head1 COPYRIGHT
 
-Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
+Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
