@@ -2,7 +2,8 @@ package Test2::IPC::Driver::Files;
 use strict;
 use warnings;
 
-our $VERSION = '0.000042';
+our $VERSION = '0.000043';
+$VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 use base 'Test2::IPC::Driver';
 
@@ -17,7 +18,7 @@ use Test2::Util qw/try get_tid pkg_to_file/;
 use Test2::API qw/test2_ipc_set_pending/;
 
 sub use_shm { 1 }
-sub shm_size { 64 }
+sub shm_size() { 64 }
 
 sub is_viable { 1 }
 
@@ -153,7 +154,7 @@ do so if Test::Builder is loaded for legacy reasons.
     my ($ok, $err) = try {
         Storable::store($e, $file);
         rename($file, $ready) or $self->abort("Could not rename file '$file' -> '$ready'");
-        test2_ipc_set_pending($file);
+        test2_ipc_set_pending(substr($file, -(shm_size)));
     };
     if (!$ok) {
         my $src_file = __FILE__;
@@ -312,10 +313,6 @@ __END__
 
 Test2::IPC::Driver::Files - Temp dir + Files concurrency model.
 
-=head1 EXPERIMENTAL RELEASE
-
-This is an experimental release. Using this right now is not recommended.
-
 =head1 DESCRIPTION
 
 This is the default, and fallback concurrency model for L<Test2>. This
@@ -351,7 +348,7 @@ See L<Test2::IPC::Driver> for methods.
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
-F<http://github.com/Test-More/Test2/>.
+F<http://github.com/Test-More/test-more/>.
 
 =head1 MAINTAINERS
 
@@ -371,7 +368,7 @@ F<http://github.com/Test-More/Test2/>.
 
 =head1 COPYRIGHT
 
-Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
+Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
